==> micro-website-base-core-1.2.2-sources.jar: com/ptteng/micro/common/service/TemplateService.java <==
package com.ptteng.micro.common.service;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;
import com.ptteng.micro.common.model.Template;
import java.util.List;
import org.osoa.sca.annotations.Remotable;

@Remotable
public interface TemplateService extends BaseDaoService {

	



   		   
		
		public Long insert(Template template)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<Template> insertList(List<Template> templateList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean delete(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean update(Template template)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean updateList(List<Template> templateList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public Template getObjectById(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<Template> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException;
		  
    	
	


			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countTemplateIdsByMerchantId(Long merchantId)throws ServiceException, ServiceDaoException;
					
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getTemplateIdsByMerchantId(Long merchantId, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
		
	
	
	
	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long> getTemplateIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException;

	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer countTemplateIds() throws ServiceException, ServiceDaoException;
	

}

==> micro-website-base-core-2.1.5-sources.jar: com/ptteng/micro/common/service/TemplateService.java <==
package com.ptteng.micro.common.service;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;
import com.ptteng.micro.common.model.Template;
import java.util.List;
import org.osoa.sca.annotations.Remotable;

@Remotable
public interface TemplateService extends BaseDaoService {

	



   		   
		
		public Long insert(Template template,String lang)throws Exception;
		  
    	   
		
		public List<Template> insertList(List<Template> templateList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean delete(Long id,String lang)throws Exception;
		  
    	   
		
		public boolean update(Template template,String lang)throws Exception;
		  
    	   
		
		public boolean updateList(List<Template> templateList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public Template getObjectById(Long id,String lang)throws Exception;
		  
    	   
		
		public List<Template> getObjectsByIds(List<Long> ids,String lang)throws Exception;
		  
    	
	


			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countTemplateIdsByMerchantId(Long merchantId)throws ServiceException, ServiceDaoException;
					
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getTemplateIdsByMerchantId(Long merchantId, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
		
	
	
	
	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long> getTemplateIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException;

	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer countTemplateIds() throws ServiceException, ServiceDaoException;
	

}
